OpenJDK 17: java.io.WriteAbortedException (deprecation)

This is part of merging upstream changes from OpenJDK 17.0.3-ga. This CL
updates java.io.WriteAbortedException class, adding deprecation for
"detail" field.

Bug: 241558442
Test: treehugger
Change-Id: I2d1150adc9b6b250cc238ecf66cfbaa984a6b360
diff --git a/api/current.txt b/api/current.txt
index e435a32..a8d6143 100755
--- a/api/current.txt
+++ b/api/current.txt
@@ -2238,7 +2238,7 @@
 
   public class WriteAbortedException extends java.io.ObjectStreamException {
     ctor public WriteAbortedException(String, Exception);
-    field public Exception detail;
+    field @Deprecated public Exception detail;
   }
 
   public abstract class Writer implements java.lang.Appendable java.io.Closeable java.io.Flushable {
diff --git a/ojluni/src/main/java/java/io/WriteAbortedException.java b/ojluni/src/main/java/java/io/WriteAbortedException.java
index 22b8f81..4ceaa90 100644
--- a/ojluni/src/main/java/java/io/WriteAbortedException.java
+++ b/ojluni/src/main/java/java/io/WriteAbortedException.java
@@ -42,12 +42,13 @@
     /**
      * Exception that was caught while writing the ObjectStream.
      *
      * <p>This field predates the general-purpose exception chaining facility.
      * The {@link Throwable#getCause()} method is now the preferred means of
      * obtaining this information.
      *
      * @serial
      */
+    @Deprecated(since="17")
     public Exception detail;
 
     /**
@@ -42,12 +42,13 @@
      * Exception that was caught while writing the ObjectStream.
      *
-     * <p>This field predates the general-purpose exception chaining facility.
-     * The {@link Throwable#getCause()} method is now the preferred means of
-     * obtaining this information.
+     * @deprecated This field predates the general-purpose exception
+     * chaining facility.  The {@link Throwable#getCause()} method is
+     * now the preferred means of obtaining this information.
      *
      * @serial